@@ -6,7 +6,7 @@ from django.conf.urls.static import static
 from django.contrib import admin
 
 
-admin.autodiscover()
+# admin.autodiscover()
 
 
 urlpatterns = patterns(
